<?php
/*
Plugin Name: Zoho Verify HTML
Description: A plugin to save and read short text for Zoho Verify HTML.
Version: 1.0
Author: Other
*/

namespace ZohoVerify;

// Prevent direct access to the file
if (!defined('ABSPATH')) {
    die('You are not allowed to call this page directly.');
}

// Add a new menu to the WP admin panel
add_action('admin_menu', 'ZohoVerify\zoho_verification_menu');
register_deactivation_hook(__FILE__, 'ZohoVerify\zoho_verification_remove_file');
add_action('admin_notices', 'ZohoVerify\zoho_verification_success_notice');
add_action('admin_init', 'ZohoVerify\zoho_verification_update_file');

function zoho_verification_menu() {
    add_options_page('Zoho Verify HTML', 'Zoho Verify HTML', 'manage_options', 'zoho-verification', 'ZohoVerify\zoho_verification_page');
}

function zoho_verification_update_file() {
    // Check if our nonce is set.
    if (!isset($_POST['zoho_verification_nonce'])) {
        return;
    }

    // Verify that the nonce is valid.
    if (!wp_verify_nonce($_POST['zoho_verification_nonce'], 'zoho_verification_update')) {
        return;
    }

    if (isset($_POST['zoho_text'])) {
        $dir_path = ABSPATH . 'zohoverify';
        if (!file_exists($dir_path)) {
            mkdir($dir_path, 0755, true);
        }
        $file_path = $dir_path . '/verifyforzoho.html';
        file_put_contents($file_path, sanitize_text_field($_POST['zoho_text']));
        set_transient('zoho_verification_updated', true, 5);
    }
}
// Display the plugin page
function zoho_verification_page() {
    $dir_path = ABSPATH . 'zohoverify';
    $file_path = $dir_path . '/verifyforzoho.html';
    $zoho_text = '';
    if (file_exists($file_path)) {
        $zoho_text = file_get_contents($file_path);
    }

    echo '<div class="wrap">';
    echo '<h1 class="wp-heading-inline">Zoho Verification</h1>';
    echo '<form method="post" action="">';
    wp_nonce_field('zoho_verification_update', 'zoho_verification_nonce');
    echo '<table class="form-table">';
    echo '<tr>';
    echo '<th scope="row"><label for="zoho_text">Enter Code:</label></th>';
    echo '<td><input type="text" id="zoho_text" name="zoho_text" value="' . esc_attr($zoho_text) . '" class="regular-text"></td>';
    echo '</tr>';
    echo '</table>';
    echo '<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="Save"></p>';
    echo '</form>';
    echo '</div>';
}

function zoho_verification_success_notice() {
    if (get_transient('zoho_verification_updated')) {
        $file_url = site_url('zohoverify/verifyforzoho.html');
        echo '<div class="notice notice-success is-dismissible">';
        echo '<p>File has been updated successfully. You can view it <a href="' . esc_url($file_url) . '" target="_blank">here</a>.</p>';
        echo '</div>';
        delete_transient('zoho_verification_updated');
    }
}

function zoho_verification_remove_file() {
    $dir_path = ABSPATH . 'zohoverify';
    $file_path = $dir_path . '/verifyforzoho.html';

    if (file_exists($file_path)) {
        unlink($file_path);
    }

    if (is_dir($dir_path)) {
        rmdir($dir_path);
    }
}
?>
